@@ -13,6 +13,7 @@ from commitizen.exceptions import (
     ExpectedExit,
     NoCommitsFoundError,
     NoPatternMapError,
+    NotAGitProjectError,
     NoVersionSpecifiedError,
 )
 
@@ -21,6 +22,9 @@ class Bump:
     """Show prompt for the user to create a guided commit."""
 
     def __init__(self, config: BaseConfig, arguments: dict):
+        if not git.is_git_project():
+            raise NotAGitProjectError()
+
         self.config: BaseConfig = config
         self.arguments: dict = arguments
         self.bump_settings: dict = {
